nbxmpp.bosh.AckChecker

Package nbxmpp :: Module bosh :: Class AckChecker |
[hide private]
[frames] | no frames]

# Class AckChecker

source code

Class for generating rids and generating and checking acknowledgements in BOSH messages

Instance Methods | [hide private]
__init__(self) | source code
get_not_acked_rids(self) | source code
backup_stanza(self, stanza, socket) | source code
process_incoming_ack(self, socket, ack=None) | source code
get_rid(self) | source code

Method Details | [hide private]

### __init__(self) (Constructor) | source code

### get_not_acked_rids(self) | source code

### backup_stanza(self, stanza, socket) | source code

### process_incoming_ack(self, socket, ack=None) | source code

### get_rid(self) | source code